<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created:	3/9/2013	ELL
// Modified: 12/2/2014	ELL
// Added checking for border areas.

	include ("check_session.php");
	
	$page_name = $_POST['page_name'];
	$special = $_POST['special'];
	if ($special == 1)
		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name='$page_name'";
	else
		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "page_data WHERE page_name='$page_name'";
	$result = $bwb_dbh->query($query);
	echo $result->rowCount();
?>